@@ -237,7 +237,7 @@ where
             Ok(Err(err)) => Err((err, item)),
             Err(err) => match err.try_into_panic() {
                 Ok(payload) => panic::resume_unwind(payload),
-                Err(err) => return Err((SerializationError::new(err), item)),
+                Err(err) => Err((SerializationError::new(err), item)),
             },
         }
     }
